pub struct HexView<'a> { /* private fields */ }Expand description
The HexView struct represents the configuration of how to display the data.
Implementations
Sourceimpl<'a> HexView<'a>
impl<'a> HexView<'a>
Sourcepub fn print(&self) -> Result<(), Error>
pub fn print(&self) -> Result<(), Error>
Prints the hextable to stdout. If any colors were given during construction, the specified ranges will be printed in color.
Sourcepub fn new(data: &[u8]) -> HexView<'_>
pub fn new(data: &[u8]) -> HexView<'_>
Constructs a new HexView for the given data without offset and using codepage 850, a row width
of 16 and . as replacement character.
pub fn fmt<W>(&self, buffer: &mut W) -> Result<(), Error>where
W: WriteColor,