pub struct Module<T> {
pub inner: Rc<Inner<T>>,
}Expand description
A cheaply-clonable, reference-counted handle to a registered module.
Fields
inner: Rc<Inner<T>>Shared inner state holding the module and its metadata.
Implementations
Sourceimpl<T> Module<T>where
T: App + 'static,
impl<T> Module<T>where
T: App + 'static,
Sourcepub fn any(&self) -> Rc<RefCell<dyn ModuleT<Context = T>>>
pub fn any(&self) -> Rc<RefCell<dyn ModuleT<Context = T>>>
Returns a cloned reference-counted handle to the inner type-erased module.
Sourcepub fn main(&self, core: &mut T)
pub fn main(&self, core: &mut T)
Runs the module’s main update step, invoking its ModuleT::main hook.
Sourcepub fn activate(&self, core: &mut T)
pub fn activate(&self, core: &mut T)
Activates the module, invoking its ModuleT::activate hook.
Sourcepub fn deactivate(&self, core: &mut T)
pub fn deactivate(&self, core: &mut T)
Deactivates the module, invoking its ModuleT::deactivate hook.
Sourcepub fn render(
&self,
core: &mut T,
ctx: &Context,
frame: &mut Frame,
ui: &mut Ui,
)
pub fn render( &self, core: &mut T, ctx: &Context, frame: &mut Frame, ui: &mut Ui, )
Applies the module’s style (mobile or default text styles) and then renders the module’s UI.
Sourcepub fn name(&self) -> &str
pub fn name(&self) -> &str
Returns the module’s display name, falling back to the derived type name when the module does not provide its own.