pub struct ModuleManager<T> { /* private fields */ }Expand description
Tracks the set of application modules and the currently active module, providing navigation between them with a back-stack history.
Implementations
Sourceimpl<T> ModuleManager<T>where
T: App,
impl<T> ModuleManager<T>where
T: App,
Sourcepub fn new(default_module: TypeId, modules: AHashMap<TypeId, Module<T>>) -> Self
pub fn new(default_module: TypeId, modules: AHashMap<TypeId, Module<T>>) -> Self
Creates a new manager from the given registry of modules, with the
module identified by default_module as the initially active module.
Sourcepub fn select<M>(&mut self, core: &mut T)where
M: 'static,
pub fn select<M>(&mut self, core: &mut T)where
M: 'static,
Activates the registered module of type M, making it the active module.
Sourcepub fn select_with_type_id(&self, type_id: TypeId, core: &mut T)
pub fn select_with_type_id(&self, type_id: TypeId, core: &mut T)
Activates the module identified by type_id, pushing the current module
onto the back-stack and scheduling it for deactivation.
Sourcepub fn has_stack(&self) -> bool
pub fn has_stack(&self) -> bool
Returns true if there are modules on the navigation back-stack.
Sourcepub fn render(&self, app: &mut T, ctx: &Context, frame: &mut Frame, ui: &mut Ui)
pub fn render(&self, app: &mut T, ctx: &Context, frame: &mut Frame, ui: &mut Ui)
Renders the currently active module and deactivates the previously active module if a switch occurred on the prior frame.
Sourcepub fn back(&mut self)
pub fn back(&mut self)
Navigates back to the most recent non-secure module on the stack, making it the active module.
Sourcepub fn purge_secure_stack(&mut self)
pub fn purge_secure_stack(&mut self)
Removes all secure modules from the navigation back-stack.
Sourcepub fn get<M>(&self) -> ModuleReference<T, M>where
M: ModuleT<Context = T> + 'static,
pub fn get<M>(&self) -> ModuleReference<T, M>where
M: ModuleT<Context = T> + 'static,
Returns a typed reference to the registered module of type M.