Module panic

Module panic 

Panic hooks that log application panics and trigger shutdown.

Functions

init_graceful_panic_handler
Installs a panic hook that writes the panic info and backtrace to application-panic.log and then triggers a graceful runtime abort.
init_ungraceful_panic_handler
Installs a panic hook that writes the panic info and backtrace to service-panic.log and then exits the process immediately.