pub fn init_graceful_panic_handler()Expand description
Installs a panic hook that writes the panic info and backtrace to
application-panic.log and then triggers a graceful runtime abort.
pub fn init_graceful_panic_handler()Installs a panic hook that writes the panic info and backtrace to
application-panic.log and then triggers a graceful runtime abort.