pub fn init_ungraceful_panic_handler()Expand description
Installs a panic hook that writes the panic info and backtrace to
service-panic.log and then exits the process immediately.
pub fn init_ungraceful_panic_handler()Installs a panic hook that writes the panic info and backtrace to
service-panic.log and then exits the process immediately.