Module payload

Module payload 

Globally-registered, shareable payload slots for passing data between tasks.

Structs

Payload
A globally-registered, cheaply-cloneable slot for handing a value of type T between async tasks and the UI, with an associated pending flag to track in-flight operations. Instances sharing the same id share the same storage.