pub trait HashMapModuleExtension<T, M> {
// Required method
fn insert_typeid(&mut self, value: M)
where M: ModuleT<Context = T> + 'static,
T: App;
}Expand description
Extension trait for inserting a module into a map keyed by its TypeId.
Required Methods
Sourcefn insert_typeid(&mut self, value: M)
fn insert_typeid(&mut self, value: M)
Inserts the module into the map, using the module type’s TypeId as
the key.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".